pub trait ToXml {
// Required method
fn to_xml(&self) -> String;
// Provided method
fn write_xml(&self, writer: &mut String) { ... }
}Expand description
Trait for types that can be converted to XML
pub trait ToXml {
// Required method
fn to_xml(&self) -> String;
// Provided method
fn write_xml(&self, writer: &mut String) { ... }
}Trait for types that can be converted to XML