SlideSection

Struct SlideSection 

pub struct SlideSection {
    pub name: String,
    pub first_slide: usize,
    pub slide_count: usize,
}
A section that groups consecutive slides

Fields

name: Stringfirst_slide: usizeslide_count: usize

Implementations

Source

impl SlideSection

pub fn new(name: &str, first_slide: usize, slide_count: usize) -> Self

Create a new section starting at a given slide index (0-based)

pub fn last_slide(&self) -> usize

Last slide index (inclusive, 0-based)

pub fn contains_slide(&self, slide_index: usize) -> bool

Check if a slide index belongs to this section