pub fn create_slide_master_xml(print: Option<&PrintSettings>) -> StringExpand description
Create slide master XML with all standard layouts and optional footer placeholders.
pub fn create_slide_master_xml(print: Option<&PrintSettings>) -> StringCreate slide master XML with all standard layouts and optional footer placeholders.